//------------------------------------------------------------------------------
// CERN BE-CEM-EDL
// General Cores Library
// https://www.ohwr.org/projects/general-cores
//------------------------------------------------------------------------------
//
// units: gencores_sim_pkg
//
// description: Shared classes and interfaces for the gencores SV simulations
//
//------------------------------------------------------------------------------
// Copyright CERN 2010-2019
//------------------------------------------------------------------------------
// Copyright and related rights are licensed under the Solderpad Hardware
// License, Version 2.0 (the "License"); you may not use this file except
// in compliance with the License. You may obtain a copy of the License at
// http://solderpad.org/licenses/SHL-2.0.
// Unless required by applicable law or agreed to in writing, software,
// hardware and materials distributed under this License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
// or implied. See the License for the specific language governing permissions
// and limitations under the License.
//------------------------------------------------------------------------------

  `include "simdrv_defs.svh"

    
  class CBusDevice;
    protected CBusAccessor m_acc;
    protected uint64_t m_base;

    function new(CBusAccessor acc, uint64_t base);
      m_acc  = acc;
      m_base = base;
    endfunction  // new

    virtual task automatic writel(uint32_t addr, uint32_t val);
      m_acc.write(m_base + addr, val);
    endtask  // writel


    virtual task automatic readl(uint32_t addr, output uint32_t val);
      automatic uint64_t val64;
      m_acc.read(m_base + addr, val64);
      val = val64;
    endtask  // readl


  virtual task automatic set_bits(uint32_t addr, uint32_t bits);
    uint32_t r;
    readl(addr, r);
    r |= bits;
    writel(addr, r);
  endtask

  virtual task automatic clear_bits(uint32_t addr, uint32_t bits);
    uint32_t r;
    readl(addr, r);
    r &= ~bits;
    writel(addr, r);
  endtask

  endclass  // CBusDevice

