`timescale 1ps/1ps

`include "simdrv_defs.svh"

`include "axi4_lite_master.sv"

module dupa;
   glbl dummy();
   afcz_wrs_8p_top dummy2();
endmodule // dupa

class IBusDevice;

   CBusAccessor m_acc;
   uint64_t m_base;

   function new ( CBusAccessor acc, uint64_t base );
      m_acc =acc;
      m_base = base;
   endfunction // new
   
   virtual task write32( uint32_t addr, uint32_t val );
      m_acc.write(m_base +addr, val);
   endtask // write
   
   virtual task read32( uint32_t addr, output uint32_t val );
      uint64_t val64;
      
      m_acc.read(m_base +addr, val64);
      val = val64;
      
   endtask // write
endclass // BusDevice
   

module main;

   reg rst_n = 0;
   reg clk_startup_62m5 = 0;
   reg clk_gth = 0;
   reg clk_20m = 0;

   always #8ns clk_startup_62m5 <= ~clk_startup_62m5;
   always #4ns clk_gth <= ~clk_gth;
   always #25ns clk_20m <= ~clk_20m;

   initial begin
      repeat(30) @(posedge clk_startup_62m5);
      rst_n = 1;
   end
   
   wire axi4l_aclk;
   wire axi4l_aresetn;
   
   IAXI4LiteMaster master ( axi4l_aclk, axi4l_aresetn );

   afcz_wrs_8p_top
     #(
       .g_simulation(1)
       )
   DUT 
     (

      .sys_rst_n_i(rst_n),
      .clk_20m_vcxo_i( clk_20m ),
      .clk_startup_i( clk_startup_62m5 ),

      .mgtclk1_224_p_i(1'b0), //clk_gth),
      .mgtclk1_224_n_i(1'b1), //~clk_gth),
      
      
      .axi4l_aclk    ( axi4l_aclk ),
      .axi4l_aresetn ( axi4l_aresetn ),
      .axi4l_arvalid ( master.arvalid ),
      .axi4l_awvalid ( master.awvalid ),
      .axi4l_bready  ( master.bready ),
      .axi4l_rready  ( master.rready),
      .axi4l_wlast   ( master.wlast ),
      .axi4l_wvalid  ( master.wvalid ),
      .axi4l_araddr  ( master.araddr ),
      .axi4l_awaddr  ( master.awaddr ),
      .axi4l_wdata   ( master.wdata ),
      .axi4l_wstrb   ( master.wstrb ),
      .axi4l_arready ( master.arready ),
      .axi4l_awready ( master.awready ),
      .axi4l_bvalid  ( master.bvalid ),
      .axi4l_rlast   ( master.rlast ),
      .axi4l_rvalid  ( master.rvalid ),
      .axi4l_wready  ( master.wready ),
      .axi4l_bresp   ( master.bresp ),
      .axi4l_rresp   ( master.rresp ),
      .axi4l_rdata   ( master.rdata )
      );

   const uint64_t base_endpoints = 'h30000;
   
   initial begin
      uint64_t rv;
      automatic CBusAccessor acc = master.get_accessor();
      int i;
      #10us;
      

      $error("WR!");

      acc.write('h10304, 'h8);
      acc.write('h54000, 'haa);
      acc.read('h54000, rv);
      $display("Rd(0) %x", rv);
      $stop;
      
      
      
      for(i=0; i<100; i+=1)
	acc.write(i*4, i);
      
      
      acc.read(0, rv); // read idcode from EP0
      $display("Rd(0) %x", rv);
     
      acc.read(base_endpoints + 'h34, rv); // read idcode from EP0
      $display("IDCode(0) %x", rv);
      
      #100ns;
      
      $stop;
   end

   
endmodule // main
